summaryrefslogtreecommitdiff
path: root/libswscale/utils.c
diff options
context:
space:
mode:
authorDerek Buitenhuis <derek.buitenhuis@gmail.com>2016-01-27 15:19:38 +0000
committerDerek Buitenhuis <derek.buitenhuis@gmail.com>2016-01-27 16:36:46 +0000
commit21f946840260da150affd9a20cc35b3d56194ba6 (patch)
tree5ca004c2ff6cf737f6858a56ce17602c339d80e6 /libswscale/utils.c
parent0aada30510d809bccfd539a90ea37b61188f2cb4 (diff)
avutil: Rename FF_CEIL_COMPAT to AV_CEIL_COMPAT
Libav, for some reason, merged this as a public API function. This will aid in future merges. A define is left for backwards compat, just in case some person used it, since it is in a public header. Signed-off-by: Derek Buitenhuis <derek.buitenhuis@gmail.com>
Diffstat (limited to 'libswscale/utils.c')
-rw-r--r--libswscale/utils.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/libswscale/utils.c b/libswscale/utils.c
index 73aefc503d..ef4241ac37 100644
--- a/libswscale/utils.c
+++ b/libswscale/utils.c
@@ -1358,11 +1358,11 @@ av_cold int sws_init_context(SwsContext *c, SwsFilter *srcFilter,
(flags & SWS_FAST_BILINEAR)))
c->chrSrcHSubSample = 1;
- // Note the FF_CEIL_RSHIFT is so that we always round toward +inf.
- c->chrSrcW = FF_CEIL_RSHIFT(srcW, c->chrSrcHSubSample);
- c->chrSrcH = FF_CEIL_RSHIFT(srcH, c->chrSrcVSubSample);
- c->chrDstW = FF_CEIL_RSHIFT(dstW, c->chrDstHSubSample);
- c->chrDstH = FF_CEIL_RSHIFT(dstH, c->chrDstVSubSample);
+ // Note the AV_CEIL_RSHIFT is so that we always round toward +inf.
+ c->chrSrcW = AV_CEIL_RSHIFT(srcW, c->chrSrcHSubSample);
+ c->chrSrcH = AV_CEIL_RSHIFT(srcH, c->chrSrcVSubSample);
+ c->chrDstW = AV_CEIL_RSHIFT(dstW, c->chrDstHSubSample);
+ c->chrDstH = AV_CEIL_RSHIFT(dstH, c->chrDstVSubSample);
FF_ALLOCZ_OR_GOTO(c, c->formatConvBuffer, FFALIGN(srcW*2+78, 16) * 2, fail);